diff --git a/database/gdb/gdb_z_mysql_feature_model_struct_test.go b/database/gdb/gdb_z_mysql_feature_model_struct_test.go
index 78dda93d5..e2886e05a 100644
--- a/database/gdb/gdb_z_mysql_feature_model_struct_test.go
+++ b/database/gdb/gdb_z_mysql_feature_model_struct_test.go
@@ -550,7 +550,7 @@ func Test_Scan_JsonAttributes(t *testing.T) {
}
table := "jfy_gift"
- array := gstr.SplitAndTrim(gtest.TestDataContent(`issue1380.sql`), ";")
+ array := gstr.SplitAndTrim(gtest.DataContent(`issue1380.sql`), ";")
for _, v := range array {
if _, err := db.Exec(ctx, v); err != nil {
gtest.Error(err)
diff --git a/database/gdb/gdb_z_mysql_feature_with_test.go b/database/gdb/gdb_z_mysql_feature_with_test.go
index 3175cb2d9..a0eb72860 100644
--- a/database/gdb/gdb_z_mysql_feature_with_test.go
+++ b/database/gdb/gdb_z_mysql_feature_with_test.go
@@ -10,7 +10,6 @@ import (
"fmt"
"testing"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/test/gtest"
@@ -1644,7 +1643,7 @@ func Test_Table_Relation_With_MultipleDepends1(t *testing.T) {
dropTable("table_b")
dropTable("table_c")
}()
- for _, v := range gstr.SplitAndTrim(gfile.GetContents(gdebug.TestDataPath("with_multiple_depends.sql")), ";") {
+ for _, v := range gstr.SplitAndTrim(gfile.GetContents(gtest.DataPath("with_multiple_depends.sql")), ";") {
if _, err := db.Exec(ctx, v); err != nil {
gtest.Error(err)
}
@@ -1716,7 +1715,7 @@ func Test_Table_Relation_With_MultipleDepends2(t *testing.T) {
dropTable("table_b")
dropTable("table_c")
}()
- for _, v := range gstr.SplitAndTrim(gfile.GetContents(gdebug.TestDataPath("with_multiple_depends.sql")), ";") {
+ for _, v := range gstr.SplitAndTrim(gfile.GetContents(gtest.DataPath("with_multiple_depends.sql")), ";") {
if _, err := db.Exec(ctx, v); err != nil {
gtest.Error(err)
}
@@ -1803,7 +1802,7 @@ func Test_Table_Relation_With_MultipleDepends_Embedded(t *testing.T) {
dropTable("table_b")
dropTable("table_c")
}()
- for _, v := range gstr.SplitAndTrim(gfile.GetContents(gdebug.TestDataPath("with_multiple_depends.sql")), ";") {
+ for _, v := range gstr.SplitAndTrim(gfile.GetContents(gtest.DataPath("with_multiple_depends.sql")), ";") {
if _, err := db.Exec(ctx, v); err != nil {
gtest.Error(err)
}
@@ -1996,7 +1995,7 @@ func Test_With_Feature_Issue1401(t *testing.T) {
table1 = "parcels"
table2 = "parcel_items"
)
- array := gstr.SplitAndTrim(gtest.TestDataContent(`issue1401.sql`), ";")
+ array := gstr.SplitAndTrim(gtest.DataContent(`issue1401.sql`), ";")
for _, v := range array {
if _, err := db.Exec(ctx, v); err != nil {
gtest.Error(err)
@@ -2038,7 +2037,7 @@ func Test_With_Feature_Issue1412(t *testing.T) {
table1 = "parcels"
table2 = "items"
)
- array := gstr.SplitAndTrim(gtest.TestDataContent(`issue1412.sql`), ";")
+ array := gstr.SplitAndTrim(gtest.DataContent(`issue1412.sql`), ";")
for _, v := range array {
if _, err := db.Exec(ctx, v); err != nil {
gtest.Error(err)
diff --git a/database/gdb/gdb_z_mysql_model_test.go b/database/gdb/gdb_z_mysql_model_test.go
index 4b941e223..01bb5499c 100644
--- a/database/gdb/gdb_z_mysql_model_test.go
+++ b/database/gdb/gdb_z_mysql_model_test.go
@@ -18,7 +18,6 @@ import (
"github.com/gogf/gf/v2/container/garray"
"github.com/gogf/gf/v2/container/gmap"
"github.com/gogf/gf/v2/database/gdb"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/encoding/gjson"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/os/gfile"
@@ -2195,7 +2194,7 @@ func Test_Model_FieldsEx_WithReservedWords(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
var (
table = "fieldsex_test_table"
- sqlTpcPath = gdebug.TestDataPath("reservedwords_table_tpl.sql")
+ sqlTpcPath = gtest.DataPath("reservedwords_table_tpl.sql")
sqlContent = gfile.GetContents(sqlTpcPath)
)
t.AssertNE(sqlContent, "")
diff --git a/debug/gdebug/gdebug_testdata.go b/debug/gdebug/gdebug_testdata.go
deleted file mode 100644
index c87f24b13..000000000
--- a/debug/gdebug/gdebug_testdata.go
+++ /dev/null
@@ -1,36 +0,0 @@
-// Copyright GoFrame Author(https://goframe.org). All Rights Reserved.
-//
-// This Source Code Form is subject to the terms of the MIT License.
-// If a copy of the MIT was not distributed with this file,
-// You can obtain one at https://github.com/gogf/gf.
-
-package gdebug
-
-import (
- "io/ioutil"
- "path/filepath"
-)
-
-// TestDataPath retrieves and returns the testdata path of current package,
-// which is used for unit testing cases only.
-// The optional parameter `names` specifies the sub-folders/sub-files,
-// which will be joined with current system separator and returned with the path.
-func TestDataPath(names ...string) string {
- path := CallerDirectory() + string(filepath.Separator) + "testdata"
- for _, name := range names {
- path += string(filepath.Separator) + name
- }
- return path
-}
-
-// TestDataContent retrieves and returns the file content for specified testdata path of current package
-func TestDataContent(names ...string) string {
- path := TestDataPath(names...)
- if path != "" {
- data, err := ioutil.ReadFile(path)
- if err == nil {
- return string(data)
- }
- }
- return ""
-}
diff --git a/encoding/gbase64/gbase64_z_unit_test.go b/encoding/gbase64/gbase64_z_unit_test.go
index 4e02ceada..65cbc6561 100644
--- a/encoding/gbase64/gbase64_z_unit_test.go
+++ b/encoding/gbase64/gbase64_z_unit_test.go
@@ -9,7 +9,6 @@ package gbase64_test
import (
"testing"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/encoding/gbase64"
"github.com/gogf/gf/v2/test/gtest"
)
@@ -66,7 +65,7 @@ func Test_Basic(t *testing.T) {
}
func Test_File(t *testing.T) {
- path := gdebug.TestDataPath("test")
+ path := gtest.DataPath("test")
expect := "dGVzdA=="
gtest.C(t, func(t *gtest.T) {
b, err := gbase64.EncodeFile(path)
diff --git a/encoding/gcompress/gcompress_z_unit_gzip_test.go b/encoding/gcompress/gcompress_z_unit_gzip_test.go
index 4bc86a615..3239e2976 100644
--- a/encoding/gcompress/gcompress_z_unit_gzip_test.go
+++ b/encoding/gcompress/gcompress_z_unit_gzip_test.go
@@ -9,7 +9,6 @@ package gcompress_test
import (
"testing"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/encoding/gcompress"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/os/gtime"
@@ -43,7 +42,7 @@ func Test_Gzip_UnGzip(t *testing.T) {
}
func Test_Gzip_UnGzip_File(t *testing.T) {
- srcPath := gdebug.TestDataPath("gzip", "file.txt")
+ srcPath := gtest.DataPath("gzip", "file.txt")
dstPath1 := gfile.Temp(gtime.TimestampNanoStr(), "gzip.zip")
dstPath2 := gfile.Temp(gtime.TimestampNanoStr(), "file.txt")
diff --git a/encoding/gcompress/gcompress_z_unit_zip_test.go b/encoding/gcompress/gcompress_z_unit_zip_test.go
index b44069d4b..3d8f51cc4 100644
--- a/encoding/gcompress/gcompress_z_unit_zip_test.go
+++ b/encoding/gcompress/gcompress_z_unit_zip_test.go
@@ -10,7 +10,6 @@ import (
"bytes"
"testing"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/encoding/gcompress"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/os/gtime"
@@ -20,8 +19,8 @@ import (
func Test_ZipPath(t *testing.T) {
// file
gtest.C(t, func(t *gtest.T) {
- srcPath := gdebug.TestDataPath("zip", "path1", "1.txt")
- dstPath := gdebug.TestDataPath("zip", "zip.zip")
+ srcPath := gtest.DataPath("zip", "path1", "1.txt")
+ dstPath := gtest.DataPath("zip", "zip.zip")
t.Assert(gfile.Exists(dstPath), false)
t.Assert(gcompress.ZipPath(srcPath, dstPath), nil)
@@ -42,8 +41,8 @@ func Test_ZipPath(t *testing.T) {
// multiple files
gtest.C(t, func(t *gtest.T) {
var (
- srcPath1 = gdebug.TestDataPath("zip", "path1", "1.txt")
- srcPath2 = gdebug.TestDataPath("zip", "path2", "2.txt")
+ srcPath1 = gtest.DataPath("zip", "path1", "1.txt")
+ srcPath2 = gtest.DataPath("zip", "path2", "2.txt")
dstPath = gfile.Temp(gtime.TimestampNanoStr(), "zip.zip")
)
if p := gfile.Dir(dstPath); !gfile.Exists(p) {
@@ -75,8 +74,8 @@ func Test_ZipPath(t *testing.T) {
// one dir and one file.
gtest.C(t, func(t *gtest.T) {
var (
- srcPath1 = gdebug.TestDataPath("zip", "path1")
- srcPath2 = gdebug.TestDataPath("zip", "path2", "2.txt")
+ srcPath1 = gtest.DataPath("zip", "path1")
+ srcPath2 = gtest.DataPath("zip", "path2", "2.txt")
dstPath = gfile.Temp(gtime.TimestampNanoStr(), "zip.zip")
)
if p := gfile.Dir(dstPath); !gfile.Exists(p) {
@@ -107,8 +106,8 @@ func Test_ZipPath(t *testing.T) {
})
// directory.
gtest.C(t, func(t *gtest.T) {
- srcPath := gdebug.TestDataPath("zip")
- dstPath := gdebug.TestDataPath("zip", "zip.zip")
+ srcPath := gtest.DataPath("zip")
+ dstPath := gtest.DataPath("zip", "zip.zip")
pwd := gfile.Pwd()
err := gfile.Chdir(srcPath)
@@ -141,10 +140,10 @@ func Test_ZipPath(t *testing.T) {
// multiple directory paths joined using char ','.
gtest.C(t, func(t *gtest.T) {
var (
- srcPath = gdebug.TestDataPath("zip")
- srcPath1 = gdebug.TestDataPath("zip", "path1")
- srcPath2 = gdebug.TestDataPath("zip", "path2")
- dstPath = gdebug.TestDataPath("zip", "zip.zip")
+ srcPath = gtest.DataPath("zip")
+ srcPath1 = gtest.DataPath("zip", "path1")
+ srcPath2 = gtest.DataPath("zip", "path2")
+ dstPath = gtest.DataPath("zip", "zip.zip")
)
pwd := gfile.Pwd()
err := gfile.Chdir(srcPath)
@@ -181,9 +180,9 @@ func Test_ZipPath(t *testing.T) {
func Test_ZipPathWriter(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
var (
- srcPath = gdebug.TestDataPath("zip")
- srcPath1 = gdebug.TestDataPath("zip", "path1")
- srcPath2 = gdebug.TestDataPath("zip", "path2")
+ srcPath = gtest.DataPath("zip")
+ srcPath1 = gtest.DataPath("zip", "path1")
+ srcPath2 = gtest.DataPath("zip", "path2")
)
pwd := gfile.Pwd()
err := gfile.Chdir(srcPath)
diff --git a/encoding/gjson/gjson_z_example_load_test.go b/encoding/gjson/gjson_z_example_load_test.go
index efe92e712..41fe9189d 100644
--- a/encoding/gjson/gjson_z_example_load_test.go
+++ b/encoding/gjson/gjson_z_example_load_test.go
@@ -9,17 +9,17 @@ package gjson_test
import (
"fmt"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/encoding/gjson"
+ "github.com/gogf/gf/v2/test/gtest"
)
func ExampleLoad() {
- jsonFilePath := gdebug.TestDataPath("json", "data1.json")
+ jsonFilePath := gtest.DataPath("json", "data1.json")
j, _ := gjson.Load(jsonFilePath)
fmt.Println(j.Get("name"))
fmt.Println(j.Get("score"))
- notExistFilePath := gdebug.TestDataPath("json", "data2.json")
+ notExistFilePath := gtest.DataPath("json", "data2.json")
j2, _ := gjson.Load(notExistFilePath)
fmt.Println(j2.Get("name"))
@@ -195,7 +195,7 @@ func ExampleIsValidDataType() {
}
func ExampleLoad_Xml() {
- jsonFilePath := gdebug.TestDataPath("xml", "data1.xml")
+ jsonFilePath := gtest.DataPath("xml", "data1.xml")
j, _ := gjson.Load(jsonFilePath)
fmt.Println(j.Get("doc.name"))
fmt.Println(j.Get("doc.score"))
diff --git a/frame/gins/gins_server.go b/frame/gins/gins_server.go
index 2455d7925..08e2277c5 100644
--- a/frame/gins/gins_server.go
+++ b/frame/gins/gins_server.go
@@ -58,10 +58,10 @@ func Server(name ...interface{}) *ghttp.Server {
}
}
}
- // Server configuration.
+ // Automatically retrieve configuration by instance name.
serverConfigMap = Config().MustGet(
ctx,
- fmt.Sprintf(`%s.%s`, configNodeName, server.GetName()),
+ fmt.Sprintf(`%s.%s`, configNodeName, instanceName),
).Map()
if len(serverConfigMap) == 0 {
serverConfigMap = Config().MustGet(ctx, configNodeName).Map()
@@ -81,7 +81,7 @@ func Server(name ...interface{}) *ghttp.Server {
// Server logger configuration checks.
serverLoggerConfigMap = Config().MustGet(
ctx,
- fmt.Sprintf(`%s.%s.%s`, configNodeName, server.GetName(), configNodeNameLogger),
+ fmt.Sprintf(`%s.%s.%s`, configNodeName, instanceName, configNodeNameLogger),
).Map()
if len(serverLoggerConfigMap) > 0 {
if err = server.Logger().SetConfigWithMap(serverLoggerConfigMap); err != nil {
diff --git a/frame/gins/gins_z_unit_config_test.go b/frame/gins/gins_z_unit_config_test.go
index ddfc98915..d635ba0c5 100644
--- a/frame/gins/gins_z_unit_config_test.go
+++ b/frame/gins/gins_z_unit_config_test.go
@@ -12,7 +12,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/gins"
"github.com/gogf/gf/v2/os/gcfg"
"github.com/gogf/gf/v2/os/gfile"
@@ -23,7 +22,7 @@ import (
var (
ctx = context.Background()
configContent = gfile.GetContents(
- gdebug.TestDataPath("config", "config.toml"),
+ gtest.DataPath("config", "config.toml"),
)
)
diff --git a/frame/gins/gins_z_unit_database_test.go b/frame/gins/gins_z_unit_database_test.go
index 5ec575660..3fc466de6 100644
--- a/frame/gins/gins_z_unit_database_test.go
+++ b/frame/gins/gins_z_unit_database_test.go
@@ -10,7 +10,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/gins"
"github.com/gogf/gf/v2/os/gcfg"
"github.com/gogf/gf/v2/os/gfile"
@@ -20,7 +19,7 @@ import (
func Test_Database(t *testing.T) {
databaseContent := gfile.GetContents(
- gdebug.TestDataPath("database", "config.toml"),
+ gtest.DataPath("database", "config.toml"),
)
gtest.C(t, func(t *gtest.T) {
var err error
diff --git a/frame/gins/gins_z_unit_redis_test.go b/frame/gins/gins_z_unit_redis_test.go
index 237db241c..9ee97d8c1 100644
--- a/frame/gins/gins_z_unit_redis_test.go
+++ b/frame/gins/gins_z_unit_redis_test.go
@@ -10,7 +10,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/gins"
"github.com/gogf/gf/v2/os/gcfg"
"github.com/gogf/gf/v2/os/gfile"
@@ -20,7 +19,7 @@ import (
func Test_Redis(t *testing.T) {
redisContent := gfile.GetContents(
- gdebug.TestDataPath("redis", "config.toml"),
+ gtest.DataPath("redis", "config.toml"),
)
gtest.C(t, func(t *gtest.T) {
diff --git a/frame/gins/gins_z_unit_server_test.go b/frame/gins/gins_z_unit_server_test.go
new file mode 100644
index 000000000..40e98435c
--- /dev/null
+++ b/frame/gins/gins_z_unit_server_test.go
@@ -0,0 +1,51 @@
+// Copyright GoFrame Author(https://goframe.org). All Rights Reserved.
+//
+// This Source Code Form is subject to the terms of the MIT License.
+// If a copy of the MIT was not distributed with this file,
+// You can obtain one at https://github.com/gogf/gf.
+
+package gins
+
+import (
+ "testing"
+
+ "github.com/gogf/gf/v2/net/ghttp"
+ "github.com/gogf/gf/v2/os/gcfg"
+ "github.com/gogf/gf/v2/os/gctx"
+ "github.com/gogf/gf/v2/test/gtest"
+)
+
+func Test_Server(t *testing.T) {
+ gtest.C(t, func(t *gtest.T) {
+ var (
+ config = Config().GetAdapter().(*gcfg.AdapterFile)
+ searchingPaths = config.GetPaths()
+ serverConfigDir = gtest.DataPath("server")
+ )
+ t.AssertNE(serverConfigDir, "")
+ t.AssertNil(config.SetPath(serverConfigDir))
+ defer func() {
+ t.AssertNil(config.SetPath(searchingPaths[0]))
+ if len(searchingPaths) > 1 {
+ t.AssertNil(config.AddPath(searchingPaths[1:]...))
+ }
+ }()
+
+ localInstances.Clear()
+ defer localInstances.Clear()
+
+ config.Clear()
+ defer config.Clear()
+
+ s := Server("tempByInstanceName")
+ s.BindHandler("/", func(r *ghttp.Request) {
+ r.Response.Write("hello")
+ })
+ s.SetDumpRouterMap(false)
+ t.AssertNil(s.Start())
+ defer t.AssertNil(s.Shutdown())
+
+ content := HttpClient().GetContent(gctx.New(), `http://127.0.0.1:8003/`)
+ t.Assert(content, `hello`)
+ })
+}
diff --git a/frame/gins/gins_z_unit_view_test.go b/frame/gins/gins_z_unit_view_test.go
index bc66d5376..aa8cae13f 100644
--- a/frame/gins/gins_z_unit_view_test.go
+++ b/frame/gins/gins_z_unit_view_test.go
@@ -11,7 +11,6 @@ import (
"fmt"
"testing"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/os/gcfg"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/os/gtime"
@@ -53,7 +52,7 @@ func Test_View(t *testing.T) {
func Test_View_Config(t *testing.T) {
// view1 test1
gtest.C(t, func(t *gtest.T) {
- dirPath := gdebug.TestDataPath("view1")
+ dirPath := gtest.DataPath("view1")
Config().GetAdapter().(*gcfg.AdapterFile).SetContent(gfile.GetContents(gfile.Join(dirPath, "config.toml")))
defer Config().GetAdapter().(*gcfg.AdapterFile).ClearContent()
defer localInstances.Clear()
@@ -75,7 +74,7 @@ func Test_View_Config(t *testing.T) {
})
// view1 test2
gtest.C(t, func(t *gtest.T) {
- dirPath := gdebug.TestDataPath("view1")
+ dirPath := gtest.DataPath("view1")
Config().GetAdapter().(*gcfg.AdapterFile).SetContent(gfile.GetContents(gfile.Join(dirPath, "config.toml")))
defer Config().GetAdapter().(*gcfg.AdapterFile).ClearContent()
defer localInstances.Clear()
@@ -97,7 +96,7 @@ func Test_View_Config(t *testing.T) {
})
// view2
gtest.C(t, func(t *gtest.T) {
- dirPath := gdebug.TestDataPath("view2")
+ dirPath := gtest.DataPath("view2")
Config().GetAdapter().(*gcfg.AdapterFile).SetContent(gfile.GetContents(gfile.Join(dirPath, "config.toml")))
defer Config().GetAdapter().(*gcfg.AdapterFile).ClearContent()
defer localInstances.Clear()
@@ -119,7 +118,7 @@ func Test_View_Config(t *testing.T) {
})
// view2
gtest.C(t, func(t *gtest.T) {
- dirPath := gdebug.TestDataPath("view2")
+ dirPath := gtest.DataPath("view2")
Config().GetAdapter().(*gcfg.AdapterFile).SetContent(gfile.GetContents(gfile.Join(dirPath, "config.toml")))
defer Config().GetAdapter().(*gcfg.AdapterFile).ClearContent()
defer localInstances.Clear()
diff --git a/frame/gins/testdata/server/config.yaml b/frame/gins/testdata/server/config.yaml
new file mode 100644
index 000000000..3be493af7
--- /dev/null
+++ b/frame/gins/testdata/server/config.yaml
@@ -0,0 +1,4 @@
+server:
+ address: ":8000"
+ tempByInstanceName:
+ address: ":8003"
\ No newline at end of file
diff --git a/i18n/gi18n/gi18n_z_unit_test.go b/i18n/gi18n/gi18n_z_unit_test.go
index d1e56db2a..aec748aad 100644
--- a/i18n/gi18n/gi18n_z_unit_test.go
+++ b/i18n/gi18n/gi18n_z_unit_test.go
@@ -24,7 +24,7 @@ import (
func Test_Basic(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
i18n := gi18n.New(gi18n.Options{
- Path: gdebug.TestDataPath("i18n"),
+ Path: gtest.DataPath("i18n"),
})
i18n.SetLanguage("none")
t.Assert(i18n.T(context.Background(), "{#hello}{#world}"), "{#hello}{#world}")
@@ -41,7 +41,7 @@ func Test_Basic(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
i18n := gi18n.New(gi18n.Options{
- Path: gdebug.TestDataPath("i18n-file"),
+ Path: gtest.DataPath("i18n-file"),
})
i18n.SetLanguage("none")
t.Assert(i18n.T(context.Background(), "{#hello}{#world}"), "{#hello}{#world}")
@@ -72,7 +72,7 @@ func Test_TranslateFormat(t *testing.T) {
// Tf
gtest.C(t, func(t *gtest.T) {
i18n := gi18n.New(gi18n.Options{
- Path: gdebug.TestDataPath("i18n"),
+ Path: gtest.DataPath("i18n"),
})
i18n.SetLanguage("none")
t.Assert(i18n.Tf(context.Background(), "{#hello}{#world} %d", 2020), "{#hello}{#world} 2020")
@@ -84,7 +84,7 @@ func Test_TranslateFormat(t *testing.T) {
func Test_DefaultManager(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
- err := gi18n.SetPath(gdebug.TestDataPath("i18n"))
+ err := gi18n.SetPath(gtest.DataPath("i18n"))
t.AssertNil(err)
gi18n.SetLanguage("none")
diff --git a/net/gclient/gclient_z_unit_test.go b/net/gclient/gclient_z_unit_test.go
index e9328bca7..a1d8dc5c0 100644
--- a/net/gclient/gclient_z_unit_test.go
+++ b/net/gclient/gclient_z_unit_test.go
@@ -15,7 +15,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/errors/gerror"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/net/gclient"
@@ -337,7 +336,7 @@ func Test_Client_File_And_Param(t *testing.T) {
time.Sleep(100 * time.Millisecond)
gtest.C(t, func(t *gtest.T) {
- path := gdebug.TestDataPath("upload", "file1.txt")
+ path := gtest.DataPath("upload", "file1.txt")
data := g.Map{
"file": "@file:" + path,
"json": `{"uuid": "luijquiopm", "isRelative": false, "fileName": "test111.xls"}`,
diff --git a/net/ghttp/ghttp_server_config.go b/net/ghttp/ghttp_server_config.go
index fff0d387e..1aa63a744 100644
--- a/net/ghttp/ghttp_server_config.go
+++ b/net/ghttp/ghttp_server_config.go
@@ -329,14 +329,18 @@ func (s *Server) SetConfigWithMap(m map[string]interface{}) error {
// SetConfig sets the configuration for the server.
func (s *Server) SetConfig(c ServerConfig) error {
s.config = c
- // Address, check and use a random free port.
+ // Automatically add ':' prefix for address if it is missed.
+ if s.config.Address != "" && !gstr.HasPrefix(s.config.Address, ":") {
+ s.config.Address = ":" + s.config.Address
+ }
+ // It checks and uses a random free port.
array := gstr.Split(s.config.Address, ":")
if s.config.Address == "" || len(array) < 2 || array[1] == "0" {
s.config.Address = gstr.Join([]string{
array[0], gconv.String(gtcp.MustGetFreePort()),
}, ":")
}
- // Static.
+ // Static files root.
if c.ServerRoot != "" {
s.SetServerRoot(c.ServerRoot)
}
diff --git a/net/ghttp/ghttp_z_unit_feature_https_test.go b/net/ghttp/ghttp_z_unit_feature_https_test.go
index f99db9b5d..f7a62426c 100644
--- a/net/ghttp/ghttp_z_unit_feature_https_test.go
+++ b/net/ghttp/ghttp_z_unit_feature_https_test.go
@@ -11,7 +11,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/net/ghttp"
_ "github.com/gogf/gf/v2/net/ghttp/testdata/https/packed"
@@ -31,8 +30,8 @@ func Test_HTTPS_Basic(t *testing.T) {
})
})
s.EnableHTTPS(
- gdebug.TestDataPath("https", "files", "server.crt"),
- gdebug.TestDataPath("https", "files", "server.key"),
+ gtest.DataPath("https", "files", "server.crt"),
+ gtest.DataPath("https", "files", "server.key"),
)
s.SetDumpRouterMap(false)
s.Start()
@@ -101,8 +100,8 @@ func Test_HTTPS_HTTP_Basic(t *testing.T) {
})
})
s.EnableHTTPS(
- gdebug.TestDataPath("https", "files", "server.crt"),
- gdebug.TestDataPath("https", "files", "server.key"),
+ gtest.DataPath("https", "files", "server.crt"),
+ gtest.DataPath("https", "files", "server.key"),
)
s.SetPort(portHttp)
s.SetHTTPSPort(portHttps)
diff --git a/net/ghttp/ghttp_z_unit_feature_middleware_basic_test.go b/net/ghttp/ghttp_z_unit_feature_middleware_basic_test.go
index bb3841daa..af81b245d 100644
--- a/net/ghttp/ghttp_z_unit_feature_middleware_basic_test.go
+++ b/net/ghttp/ghttp_z_unit_feature_middleware_basic_test.go
@@ -13,7 +13,6 @@ import (
"time"
"github.com/gogf/gf/v2/container/garray"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/net/ghttp"
"github.com/gogf/gf/v2/test/gtest"
@@ -168,7 +167,7 @@ func Test_Middleware_With_Static(t *testing.T) {
})
})
s.SetDumpRouterMap(false)
- s.SetServerRoot(gdebug.TestDataPath("static1"))
+ s.SetServerRoot(gtest.DataPath("static1"))
s.Start()
defer s.Shutdown()
time.Sleep(100 * time.Millisecond)
@@ -236,7 +235,7 @@ func Test_Middleware_Hook_With_Static(t *testing.T) {
})
})
s.SetDumpRouterMap(false)
- s.SetServerRoot(gdebug.TestDataPath("static1"))
+ s.SetServerRoot(gtest.DataPath("static1"))
s.Start()
defer s.Shutdown()
time.Sleep(100 * time.Millisecond)
diff --git a/net/ghttp/ghttp_z_unit_feature_request_file_test.go b/net/ghttp/ghttp_z_unit_feature_request_file_test.go
index 509a01897..53f020045 100644
--- a/net/ghttp/ghttp_z_unit_feature_request_file_test.go
+++ b/net/ghttp/ghttp_z_unit_feature_request_file_test.go
@@ -12,7 +12,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/net/ghttp"
"github.com/gogf/gf/v2/os/gfile"
@@ -46,7 +45,7 @@ func Test_Params_File_Single(t *testing.T) {
client := g.Client()
client.SetPrefix(fmt.Sprintf("http://127.0.0.1:%d", s.GetListenedPort()))
- srcPath := gdebug.TestDataPath("upload", "file1.txt")
+ srcPath := gtest.DataPath("upload", "file1.txt")
dstPath := gfile.Join(dstDirPath, "file1.txt")
content := client.PostContent(ctx, "/upload/single", g.Map{
"file": "@file:" + srcPath,
@@ -62,7 +61,7 @@ func Test_Params_File_Single(t *testing.T) {
client := g.Client()
client.SetPrefix(fmt.Sprintf("http://127.0.0.1:%d", s.GetListenedPort()))
- srcPath := gdebug.TestDataPath("upload", "file2.txt")
+ srcPath := gtest.DataPath("upload", "file2.txt")
content := client.PostContent(ctx, "/upload/single", g.Map{
"file": "@file:" + srcPath,
"randomlyRename": true,
@@ -97,7 +96,7 @@ func Test_Params_File_CustomName(t *testing.T) {
client := g.Client()
client.SetPrefix(fmt.Sprintf("http://127.0.0.1:%d", s.GetListenedPort()))
- srcPath := gdebug.TestDataPath("upload", "file1.txt")
+ srcPath := gtest.DataPath("upload", "file1.txt")
dstPath := gfile.Join(dstDirPath, "my.txt")
content := client.PostContent(ctx, "/upload/single", g.Map{
"file": "@file:" + srcPath,
@@ -132,8 +131,8 @@ func Test_Params_File_Batch(t *testing.T) {
client := g.Client()
client.SetPrefix(fmt.Sprintf("http://127.0.0.1:%d", s.GetListenedPort()))
- srcPath1 := gdebug.TestDataPath("upload", "file1.txt")
- srcPath2 := gdebug.TestDataPath("upload", "file2.txt")
+ srcPath1 := gtest.DataPath("upload", "file1.txt")
+ srcPath2 := gtest.DataPath("upload", "file2.txt")
dstPath1 := gfile.Join(dstDirPath, "file1.txt")
dstPath2 := gfile.Join(dstDirPath, "file2.txt")
content := client.PostContent(ctx, "/upload/batch", g.Map{
@@ -152,8 +151,8 @@ func Test_Params_File_Batch(t *testing.T) {
client := g.Client()
client.SetPrefix(fmt.Sprintf("http://127.0.0.1:%d", s.GetListenedPort()))
- srcPath1 := gdebug.TestDataPath("upload", "file1.txt")
- srcPath2 := gdebug.TestDataPath("upload", "file2.txt")
+ srcPath1 := gtest.DataPath("upload", "file1.txt")
+ srcPath2 := gtest.DataPath("upload", "file2.txt")
content := client.PostContent(ctx, "/upload/batch", g.Map{
"file[0]": "@file:" + srcPath1,
"file[1]": "@file:" + srcPath2,
@@ -205,7 +204,7 @@ func Test_Params_Strict_Route_File_Single(t *testing.T) {
client := g.Client()
client.SetPrefix(fmt.Sprintf("http://127.0.0.1:%d", s.GetListenedPort()))
- srcPath := gdebug.TestDataPath("upload", "file1.txt")
+ srcPath := gtest.DataPath("upload", "file1.txt")
dstPath := gfile.Join(dstDirPath, "file1.txt")
content := client.PostContent(ctx, "/upload/single", g.Map{
"file": "@file:" + srcPath,
diff --git a/net/ghttp/ghttp_z_unit_feature_static_test.go b/net/ghttp/ghttp_z_unit_feature_static_test.go
index da5e5df90..840a7e4d3 100644
--- a/net/ghttp/ghttp_z_unit_feature_static_test.go
+++ b/net/ghttp/ghttp_z_unit_feature_static_test.go
@@ -13,7 +13,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/test/gtest"
@@ -60,7 +59,7 @@ func Test_Static_ServerRoot(t *testing.T) {
func Test_Static_ServerRoot_Security(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
s := g.Server(guid.S())
- s.SetServerRoot(gdebug.TestDataPath("static1"))
+ s.SetServerRoot(gtest.DataPath("static1"))
s.Start()
defer s.Shutdown()
time.Sleep(100 * time.Millisecond)
diff --git a/net/ghttp/ghttp_z_unit_feature_template_test.go b/net/ghttp/ghttp_z_unit_feature_template_test.go
index 8c41f443f..ab64c506b 100644
--- a/net/ghttp/ghttp_z_unit_feature_template_test.go
+++ b/net/ghttp/ghttp_z_unit_feature_template_test.go
@@ -13,7 +13,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/encoding/ghtml"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/net/ghttp"
@@ -24,7 +23,7 @@ import (
func Test_Template_Basic(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
- v := gview.New(gdebug.TestDataPath("template", "basic"))
+ v := gview.New(gtest.DataPath("template", "basic"))
s := g.Server(guid.S())
s.SetView(v)
s.BindHandler("/", func(r *ghttp.Request) {
@@ -47,7 +46,7 @@ func Test_Template_Basic(t *testing.T) {
func Test_Template_Encode(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
- v := gview.New(gdebug.TestDataPath("template", "basic"))
+ v := gview.New(gtest.DataPath("template", "basic"))
v.SetAutoEncode(true)
s := g.Server(guid.S())
s.SetView(v)
@@ -71,7 +70,7 @@ func Test_Template_Encode(t *testing.T) {
func Test_Template_Layout1(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
- v := gview.New(gdebug.TestDataPath("template", "layout1"))
+ v := gview.New(gtest.DataPath("template", "layout1"))
s := g.Server(guid.S())
s.SetView(v)
s.BindHandler("/layout", func(r *ghttp.Request) {
@@ -99,7 +98,7 @@ func Test_Template_Layout1(t *testing.T) {
func Test_Template_Layout2(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
- v := gview.New(gdebug.TestDataPath("template", "layout2"))
+ v := gview.New(gtest.DataPath("template", "layout2"))
s := g.Server(guid.S())
s.SetView(v)
s.BindHandler("/main1", func(r *ghttp.Request) {
diff --git a/net/ghttp/ghttp_z_unit_issue_test.go b/net/ghttp/ghttp_z_unit_issue_test.go
index f8e3b437e..0e5a1ca5f 100644
--- a/net/ghttp/ghttp_z_unit_issue_test.go
+++ b/net/ghttp/ghttp_z_unit_issue_test.go
@@ -12,7 +12,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/net/ghttp"
"github.com/gogf/gf/v2/test/gtest"
@@ -45,7 +44,7 @@ func Test_Issue1611(t *testing.T) {
s := g.Server(guid.S())
v := g.View(guid.S())
content := "This is header"
- gtest.AssertNil(v.SetPath(gdebug.TestDataPath("issue1611")))
+ gtest.AssertNil(v.SetPath(gtest.DataPath("issue1611")))
s.SetView(v)
s.BindHandler("/", func(r *ghttp.Request) {
gtest.AssertNil(r.Response.WriteTpl("index/layout.html", g.Map{
diff --git a/os/gcfg/gcfg_adapter_file_path.go b/os/gcfg/gcfg_adapter_file_path.go
index bd83a3fe5..1db5c0189 100644
--- a/os/gcfg/gcfg_adapter_file_path.go
+++ b/os/gcfg/gcfg_adapter_file_path.go
@@ -85,7 +85,17 @@ func (c *AdapterFile) SetPath(path string) (err error) {
}
// AddPath adds an absolute or relative path to the search paths.
-func (c *AdapterFile) AddPath(path string) (err error) {
+func (c *AdapterFile) AddPath(paths ...string) (err error) {
+ for _, path := range paths {
+ if err = c.doAddPath(path); err != nil {
+ return err
+ }
+ }
+ return nil
+}
+
+// doAddPath adds an absolute or relative path to the search paths.
+func (c *AdapterFile) doAddPath(path string) (err error) {
var (
isDir = false
realPath = ""
@@ -139,6 +149,11 @@ func (c *AdapterFile) AddPath(path string) (err error) {
return nil
}
+// GetPaths returns the searching path array of current configuration manager.
+func (c *AdapterFile) GetPaths() []string {
+ return c.searchPaths.Slice()
+}
+
// doGetFilePath returns the absolute configuration file path for the given filename by `file`.
// If `file` is not passed, it returns the configuration file path of the default name.
// It returns an empty `path` string and an error if the given `file` does not exist.
diff --git a/os/gcfg/gcfg_z_unit_instance_test.go b/os/gcfg/gcfg_z_unit_instance_test.go
index 3cc5997b4..47bf3cbda 100644
--- a/os/gcfg/gcfg_z_unit_instance_test.go
+++ b/os/gcfg/gcfg_z_unit_instance_test.go
@@ -13,7 +13,6 @@ import (
"testing"
"github.com/gogf/gf/v2/container/gmap"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/os/genv"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/test/gtest"
@@ -60,7 +59,7 @@ func Test_Instance_AutoLocateConfigFile(t *testing.T) {
// Automatically locate the configuration file with supported file extensions.
gtest.C(t, func(t *gtest.T) {
pwd := gfile.Pwd()
- t.AssertNil(gfile.Chdir(gdebug.TestDataPath()))
+ t.AssertNil(gfile.Chdir(gtest.DataPath()))
defer gfile.Chdir(pwd)
t.Assert(Instance("c1") != nil, true)
t.Assert(Instance("c1").MustGet(ctx, "my-config"), "1")
@@ -69,7 +68,7 @@ func Test_Instance_AutoLocateConfigFile(t *testing.T) {
// Automatically locate the configuration file with supported file extensions.
gtest.C(t, func(t *gtest.T) {
pwd := gfile.Pwd()
- t.AssertNil(gfile.Chdir(gdebug.TestDataPath("folder1")))
+ t.AssertNil(gfile.Chdir(gtest.DataPath("folder1")))
defer gfile.Chdir(pwd)
t.Assert(Instance("c2").MustGet(ctx, "my-config"), 2)
})
@@ -77,7 +76,7 @@ func Test_Instance_AutoLocateConfigFile(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
localInstances.Clear()
pwd := gfile.Pwd()
- t.AssertNil(gfile.Chdir(gdebug.TestDataPath("default")))
+ t.AssertNil(gfile.Chdir(gtest.DataPath("default")))
defer gfile.Chdir(pwd)
t.Assert(Instance().MustGet(ctx, "my-config"), 1)
@@ -90,7 +89,7 @@ func Test_Instance_AutoLocateConfigFile(t *testing.T) {
func Test_Instance_EnvPath(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
- genv.Set("GF_GCFG_PATH", gdebug.TestDataPath("envpath"))
+ genv.Set("GF_GCFG_PATH", gtest.DataPath("envpath"))
defer genv.Set("GF_GCFG_PATH", "")
t.Assert(Instance("c3") != nil, true)
t.Assert(Instance("c3").MustGet(ctx, "my-config"), "3")
@@ -101,7 +100,7 @@ func Test_Instance_EnvPath(t *testing.T) {
func Test_Instance_EnvFile(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
- genv.Set("GF_GCFG_PATH", gdebug.TestDataPath("envfile"))
+ genv.Set("GF_GCFG_PATH", gtest.DataPath("envfile"))
defer genv.Set("GF_GCFG_PATH", "")
genv.Set("GF_GCFG_FILE", "c6.json")
defer genv.Set("GF_GCFG_FILE", "")
diff --git a/os/gfile/gfile_z_unit_scan_test.go b/os/gfile/gfile_z_unit_scan_test.go
index 42e80faf5..151488313 100644
--- a/os/gfile/gfile_z_unit_scan_test.go
+++ b/os/gfile/gfile_z_unit_scan_test.go
@@ -10,13 +10,12 @@ import (
"testing"
"github.com/gogf/gf/v2/container/garray"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/test/gtest"
)
func Test_ScanDir(t *testing.T) {
- teatPath := gdebug.TestDataPath()
+ teatPath := gtest.DataPath()
gtest.C(t, func(t *gtest.T) {
files, err := gfile.ScanDir(teatPath, "*", false)
t.AssertNil(err)
@@ -35,7 +34,7 @@ func Test_ScanDir(t *testing.T) {
}
func Test_ScanDirFunc(t *testing.T) {
- teatPath := gdebug.TestDataPath()
+ teatPath := gtest.DataPath()
gtest.C(t, func(t *gtest.T) {
files, err := gfile.ScanDirFunc(teatPath, "*", true, func(path string) string {
if gfile.Name(path) != "file1" {
@@ -50,7 +49,7 @@ func Test_ScanDirFunc(t *testing.T) {
}
func Test_ScanDirFile(t *testing.T) {
- teatPath := gdebug.TestDataPath()
+ teatPath := gtest.DataPath()
gtest.C(t, func(t *gtest.T) {
files, err := gfile.ScanDirFile(teatPath, "*", false)
t.AssertNil(err)
@@ -67,7 +66,7 @@ func Test_ScanDirFile(t *testing.T) {
}
func Test_ScanDirFileFunc(t *testing.T) {
- teatPath := gdebug.TestDataPath()
+ teatPath := gtest.DataPath()
gtest.C(t, func(t *gtest.T) {
array := garray.New()
files, err := gfile.ScanDirFileFunc(teatPath, "*", false, func(path string) string {
diff --git a/os/gres/gres_z_unit_test.go b/os/gres/gres_z_unit_test.go
index 2a5b424c7..b1dc65d82 100644
--- a/os/gres/gres_z_unit_test.go
+++ b/os/gres/gres_z_unit_test.go
@@ -12,7 +12,6 @@ import (
_ "github.com/gogf/gf/v2/os/gres/testdata/data"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/os/gres"
@@ -23,7 +22,7 @@ import (
func Test_PackToGoFile(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
var (
- srcPath = gdebug.TestDataPath("files")
+ srcPath = gtest.DataPath("files")
goFilePath = gfile.Temp(gtime.TimestampNanoStr(), "testdata.go")
pkgName = "testdata"
err = gres.PackToGoFile(srcPath, goFilePath, pkgName)
@@ -36,7 +35,7 @@ func Test_PackToGoFile(t *testing.T) {
func Test_Pack(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
var (
- srcPath = gdebug.TestDataPath("files")
+ srcPath = gtest.DataPath("files")
data, err = gres.Pack(srcPath)
)
t.AssertNil(err)
@@ -51,7 +50,7 @@ func Test_Pack(t *testing.T) {
func Test_PackToFile(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
var (
- srcPath = gdebug.TestDataPath("files")
+ srcPath = gtest.DataPath("files")
dstPath = gfile.Temp(gtime.TimestampNanoStr())
err = gres.PackToFile(srcPath, dstPath)
)
@@ -69,7 +68,7 @@ func Test_PackToFile(t *testing.T) {
func Test_PackMulti(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
var (
- srcPath = gdebug.TestDataPath("files")
+ srcPath = gtest.DataPath("files")
goFilePath = gfile.Temp(gtime.TimestampNanoStr(), "data.go")
pkgName = "data"
array, err = gfile.ScanDir(srcPath, "*", false)
@@ -84,7 +83,7 @@ func Test_PackMulti(t *testing.T) {
func Test_PackWithPrefix1(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
var (
- srcPath = gdebug.TestDataPath("files")
+ srcPath = gtest.DataPath("files")
goFilePath = gfile.Temp(gtime.TimestampNanoStr(), "testdata.go")
pkgName = "testdata"
err = gres.PackToGoFile(srcPath, goFilePath, pkgName, "www/gf-site/test")
@@ -97,7 +96,7 @@ func Test_PackWithPrefix1(t *testing.T) {
func Test_PackWithPrefix2(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
var (
- srcPath = gdebug.TestDataPath("files")
+ srcPath = gtest.DataPath("files")
goFilePath = gfile.Temp(gtime.TimestampNanoStr(), "testdata.go")
pkgName = "testdata"
err = gres.PackToGoFile(srcPath, goFilePath, pkgName, "/var/www/gf-site/test")
diff --git a/os/gview/gview_z_unit_config_test.go b/os/gview/gview_z_unit_config_test.go
index f8c125b5e..f138203c0 100644
--- a/os/gview/gview_z_unit_config_test.go
+++ b/os/gview/gview_z_unit_config_test.go
@@ -10,7 +10,6 @@ import (
"context"
"testing"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/os/gview"
"github.com/gogf/gf/v2/test/gtest"
@@ -19,7 +18,7 @@ import (
func Test_Config(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
config := gview.Config{
- Paths: []string{gdebug.TestDataPath("config")},
+ Paths: []string{gtest.DataPath("config")},
Data: g.Map{
"name": "gf",
},
@@ -46,7 +45,7 @@ func Test_ConfigWithMap(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
view := gview.New()
err := view.SetConfigWithMap(g.Map{
- "Paths": []string{gdebug.TestDataPath("config")},
+ "Paths": []string{gtest.DataPath("config")},
"DefaultFile": "test.html",
"Delimiters": []string{"${", "}"},
"Data": g.Map{
diff --git a/os/gview/gview_z_unit_feature_encode_test.go b/os/gview/gview_z_unit_feature_encode_test.go
index 55a3665ba..786f98a4b 100644
--- a/os/gview/gview_z_unit_feature_encode_test.go
+++ b/os/gview/gview_z_unit_feature_encode_test.go
@@ -10,7 +10,6 @@ import (
"context"
"testing"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/os/gfile"
"github.com/gogf/gf/v2/os/gview"
@@ -20,7 +19,7 @@ import (
func Test_Encode_Parse(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
v := gview.New()
- v.SetPath(gdebug.TestDataPath("tpl"))
+ v.SetPath(gtest.DataPath("tpl"))
v.SetAutoEncode(true)
result, err := v.Parse(context.TODO(), "encode.tpl", g.Map{
"title": "my title",
@@ -33,7 +32,7 @@ func Test_Encode_Parse(t *testing.T) {
func Test_Encode_ParseContent(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
v := gview.New()
- tplContent := gfile.GetContents(gdebug.TestDataPath("tpl", "encode.tpl"))
+ tplContent := gfile.GetContents(gtest.DataPath("tpl", "encode.tpl"))
v.SetAutoEncode(true)
result, err := v.ParseContent(context.TODO(), tplContent, g.Map{
"title": "my title",
diff --git a/os/gview/gview_z_unit_i18n_test.go b/os/gview/gview_z_unit_i18n_test.go
index 5b22b8250..dfd1e4026 100644
--- a/os/gview/gview_z_unit_i18n_test.go
+++ b/os/gview/gview_z_unit_i18n_test.go
@@ -23,7 +23,7 @@ func Test_I18n(t *testing.T) {
expect2 := `john says "こんにちは世界!"`
expect3 := `john says "{#hello}{#world}!"`
- g.I18n().SetPath(gdebug.TestDataPath("i18n"))
+ g.I18n().SetPath(gtest.DataPath("i18n"))
g.I18n().SetLanguage("zh-CN")
result1, err := g.View().ParseContent(context.TODO(), content, g.Map{
diff --git a/os/gview/gview_z_unit_test.go b/os/gview/gview_z_unit_test.go
index 10468557d..cfead2fc9 100644
--- a/os/gview/gview_z_unit_test.go
+++ b/os/gview/gview_z_unit_test.go
@@ -14,7 +14,6 @@ import (
"testing"
"time"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/encoding/ghtml"
"github.com/gogf/gf/v2/frame/g"
"github.com/gogf/gf/v2/os/gctx"
@@ -534,7 +533,7 @@ func Test_BuildInFuncDivide(t *testing.T) {
func Test_Issue1416(t *testing.T) {
gtest.C(t, func(t *gtest.T) {
v := gview.New()
- err := v.SetPath(gdebug.TestDataPath("issue1416"))
+ err := v.SetPath(gtest.DataPath("issue1416"))
t.AssertNil(err)
r, err := v.ParseOption(context.TODO(), gview.Option{
File: "gview.tpl",
diff --git a/util/gvalid/gvalid_z_unit_feature_i18n_test.go b/util/gvalid/gvalid_z_unit_feature_i18n_test.go
index 2554f1837..d43d4c566 100644
--- a/util/gvalid/gvalid_z_unit_feature_i18n_test.go
+++ b/util/gvalid/gvalid_z_unit_feature_i18n_test.go
@@ -10,7 +10,6 @@ import (
"context"
"testing"
- "github.com/gogf/gf/v2/debug/gdebug"
"github.com/gogf/gf/v2/i18n/gi18n"
"github.com/gogf/gf/v2/test/gtest"
"github.com/gogf/gf/v2/util/gvalid"
@@ -19,7 +18,7 @@ import (
func TestValidator_I18n(t *testing.T) {
var (
err gvalid.Error
- i18nManager = gi18n.New(gi18n.Options{Path: gdebug.TestDataPath("i18n")})
+ i18nManager = gi18n.New(gi18n.Options{Path: gtest.DataPath("i18n")})
ctxCn = gi18n.WithLanguage(context.TODO(), "cn")
validator = gvalid.New().I18n(i18nManager)
)
diff --git a/test/gtest/gtest_util.go b/test/gtest/gtest_util.go
index 6ecb4bd9a..8cc511770 100644
--- a/test/gtest/gtest_util.go
+++ b/test/gtest/gtest_util.go
@@ -345,11 +345,11 @@ func AssertNil(value interface{}) {
AssertNE(value, nil)
}
// TestDataPath retrieves and returns the testdata path of current package,
// which is used for unit testing cases only.
// The optional parameter `names` specifies the sub-folders/sub-files,
// which will be joined with current system separator and returned with the path.
-func TestDataPath(names ...string) string {
+func DataPath(names ...string) string {
_, path, _ := gdebug.CallerWithFilter([]string{pathFilterKey})
path = filepath.Dir(path) + string(filepath.Separator) + "testdata"
for _, name := range names {
@@ -358,9 +358,9 @@ func TestDataPath(names ...string) string {
return path
}
-// TestDataContent retrieves and returns the file content for specified testdata path of current package
-func TestDataContent(names ...string) string {
- path := TestDataPath(names...)
+// DataContent retrieves and returns the file content for specified testdata path of current package
+func DataContent(names ...string) string {
+ path := DataPath(names...)
if path != "" {
data, err := ioutil.ReadFile(path)
if err == nil {
@@ -345,11 +345,11 @@ func AssertNil(value interface{}) {
AssertNE(value, nil)
}
-// TestDataPath retrieves and returns the testdata path of current package,
+// DataPath retrieves and returns the testdata path of current package,
// which is used for unit testing cases only.
// The optional parameter `names` specifies the sub-folders/sub-files,